package com.persagy.dmp.starter.alarm.aspect;

import com.persagy.dmp.starter.alarm.feign.DmpResult;
import feign.Response;
import lombok.extern.slf4j.Slf4j;
import org.aspectj.lang.annotation.AfterReturning;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Before;
import org.aspectj.lang.annotation.Pointcut;
import org.springframework.stereotype.Component;

/**
 * @description: AlarmClient切面，处理feign调用接口，接口返回值异常的情况
 * @author: lixing
 * @company: Persagy Technology Co.,Ltd
 * @since: 2020/11/27 3:56 下午
 * @version: V1.0
 **/
@Slf4j
@Aspect
@Component
public class AlarmClientAspect {
    @Pointcut("execution(public * com.persagy.dmp.starter.alarm.feign.client.*.*(..))")
    public void feignPointCut() {
    }

    @Before("feignPointCut()")
    public void before() {
    }

    @AfterReturning(returning = "res", pointcut = "feignPointCut()")
    public void after(DmpResult res) {
        if (DmpResult.FAILURE.equals(res.getResult())) {
            throw new RuntimeException(res.getMessage());
        }
    }
}
