package com.persagy.dmp.starter.alarm.communication.netty;

import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.annotation.JSONField;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;

import java.util.List;

/**
 * @description: netty报警消息格式定义
 * @author: lixing
 * @company: Persagy Technology Co.,Ltd
 * @since: 2020/11/30 10:52 上午
 * @version: V1.0
 */
@Getter
@Setter
@NoArgsConstructor
public class NettyAlarmMessage<T> {
    /**
     * 唯一标识
     */
    @JSONField()
    private long streamId;
    @JSONField()
    private int version = 1;

    /**
     * 操作类型：
     * 200-建立连接，200的source是projectId
     * 1-请求、2 -响应、3-通知、
     * 4-边缘端获取报警定义、
     * 5-边缘端主动推送报警记录、
     * 6-边缘端主动更新报警记录状态、
     * 7-云端推送修改的报警定义给边缘端(增量新增修改报警定义)、
     * 8-云端把报警记录的id推送到边缘端
     * 9-边缘端取报警定义，云端推送给边缘端的标记(全量报警定义)
     * 10-云端推送删除的报警定义给边缘端(增量删除报警定义)、
     */
    @JSONField()
    private int opCode;

    /**
     * 请求来源
     */
    @JSONField()
    private String source = "group";

    /**
     * 用于项目控制程序清除之前的时间和命令
     */
    @JSONField()
    private String clearBeforeTimeFlag;

    /**
     * 传输内容
     */
    @JSONField(jsonDirect = true)
    private List<T> content;

    /**
     * 成功标识
     */
    @JSONField()
    private Boolean success;

    @Override
    public String toString() {
        return JSONObject.toJSONString(this);
    }

    public NettyAlarmMessage(int opCode, List<T> content) {
        this.opCode = opCode;
        this.content = content;
    }
}
