package com.persagy.dmp.starter.alarm.feign;

import feign.Feign;
import feign.Logger;
import feign.Retryer;
import feign.querymap.BeanQueryMapEncoder;
import org.springframework.cloud.openfeign.EnableFeignClients;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Primary;

/**
 * @description: Feign配置
 * @author: xingmaojun
 * @company: Persagy Technology Co.,Ltd
 * @since: 2020/10/14 9:15
 * @version: V1.0
 **/

@Configuration
@EnableFeignClients(basePackages = "com.persagy.dmp.starter.alarm.feign.client")
public class AlarmFeignConfig {

    /**
     * @description: feign日志配置
     * @return: feign.Logger.Level
     * @author: xingmaojun
     * @company: Persagy Technology Co.,Ltd
     * @since: 2020/10/21 17:01
     * @version: V1.0
     */
    @Bean
    Logger.Level alarmFeignLoggerLevel() {
        //这里记录所有，根据实际情况选择合适的日志level
        return Logger.Level.FULL;
    }

    @Bean
    Logger alarmFeignLogger(){
        return new AlarmFeignLogger();
    }

    /**
     * @description: 替换解析queryMap的类，实现父类中变量的映射
     * @return: feign.Feign.Builder
     * @author: xingmaojun
     * @company: Persagy Technology Co.,Ltd
     * @since: 2020/10/21 17:01
     * @version: V1.0
     */
    @Bean
    @Primary
    public Feign.Builder alarmFeignBuilder() {
        return Feign.builder()
                .queryMapEncoder(new BeanQueryMapEncoder())
                .retryer(Retryer.NEVER_RETRY);
    }

}