package com.persagy.dmp.starter.alarm.service;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.persagy.dmp.alarm.jms.model.OrderStateMessage;
import com.persagy.dmp.starter.alarm.feign.DmpResult;
import com.persagy.dmp.starter.alarm.feign.client.AlarmClient;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

/**
 * @description: 工单状态变化处理
 * @author: lixing
 * @company: Persagy Technology Co.,Ltd
 * @since: 2020/12/16 9:45 上午
 * @version: V1.0
 **/
@Service
public class OrderStateChangeService extends BaseService {
    @Autowired
    private AlarmClient alarmClient;

    /**
     * @description: 当工单状态变化时，更新报警记录
     * @param: orderStateMessage
     * @return: void
     * @exception:
     * @author: lixing
     * @company: Persagy Technology Co.,Ltd
     * @since: 2020/12/16 10:24 上午
     * @version: V1.0
     */
    public void updateAlarmWhenOrderStateChange(OrderStateMessage orderStateMessage) throws Exception {
        // 根据工单状态获取对应的报警处理状态
        Integer alarmTreatState = getAlarmTreatState(orderStateMessage.getOrder_state());
        if (alarmTreatState == null) {
            return;
        }

        // 根据工单id获取要修改的报警记录
        JSONArray alarmRecords = getAlarmRecordsByOrderId(orderStateMessage.getOrder_id());
        if (CollectionUtils.isEmpty(alarmRecords)) {
            return;
        }

        // 更新报警记录状态
        for (Object alarmRecord : alarmRecords) {
            JSONObject alarmRecordObj = (JSONObject) alarmRecord;
            alarmRecordObj.put("treatState", alarmTreatState);
            alarmRecordObj.put("orderState", orderStateMessage.getOrder_state());
            alarmRecordObj.put("userId", "system");
            alarmClient.updateAlarmRecord(getAlarmUrlParam(alarmRecordObj), alarmRecordObj);
        }
    }

    /**
     * @description: 根据工单id获取对应的报警记录
     * @param: orderId
     * @return: JSONArray
     * @exception:
     * @author: lixing
     * @company: Persagy Technology Co.,Ltd
     * @since: 2020/12/16 10:16 上午
     * @version: V1.0
     */
    private JSONArray getAlarmRecordsByOrderId(String orderId) throws Exception {
        JSONObject queryBody = new JSONObject();
        queryBody.put("orderId", orderId);
        queryBody.put("userId", "system");
        queryBody.put("projectId", "0");
        queryBody.put("groupCode", "0");
        queryBody.put("appId", "0");
        DmpResult<JSONArray> alarmRecordDmpResult = alarmClient.queryAlarmRecord(getAlarmUrlParam(queryBody), getRequestBody(queryBody));
        String resultSuccess = "success";
        if (resultSuccess.equals(alarmRecordDmpResult.getResult())) {
            return alarmRecordDmpResult.getData();
        } else {
            return null;
        }
    }

    /**
     * @description: 根据工单状态获取对应的报警处理状态
     * @param: orderState 工单状态
     * @return: java.lang.Integer
     * @exception:
     * @author: lixing
     * @company: Persagy Technology Co.,Ltd
     * @since: 2020/12/16 9:58 上午
     * @version: V1.0
     */
    public Integer getAlarmTreatState(int orderState) {
        int handling = 2, done = 3;
        switch (orderState) {
            case 4:
            case 5:
            case 6:
                return handling;
            case 7:
            case 8:
            case 9:
            case 10:
                return done;
            default:
                return null;
        }
    }
}
